==> elasticsearch-java-7.15.1-sources.jar: co/elastic/clients/elasticsearch/watcher/HttpInputRequestResult.java <==
/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

//----------------------------------------------------
// THIS CODE IS GENERATED. MANUAL EDITS WILL BE LOST.
//----------------------------------------------------

package co.elastic.clients.elasticsearch.watcher;

import co.elastic.clients.json.DelegatingDeserializer;
import co.elastic.clients.json.JsonpDeserializable;
import co.elastic.clients.json.JsonpDeserializer;
import co.elastic.clients.json.ObjectBuilderDeserializer;
import co.elastic.clients.json.ObjectDeserializer;
import co.elastic.clients.util.ObjectBuilder;
import jakarta.json.stream.JsonGenerator;
import java.util.Objects;
import java.util.function.Function;

// typedef: watcher._types.HttpInputRequestResult
@JsonpDeserializable
public final class HttpInputRequestResult extends HttpInputRequestDefinition {
	// ---------------------------------------------------------------------------------------------

	public HttpInputRequestResult(Builder builder) {
		super(builder);

	}

	public HttpInputRequestResult(Function<Builder, Builder> fn) {
		this(fn.apply(new Builder()));
	}

	// ---------------------------------------------------------------------------------------------

	/**
	 * Builder for {@link HttpInputRequestResult}.
	 */
	public static class Builder extends HttpInputRequestDefinition.AbstractBuilder<Builder>
			implements
				ObjectBuilder<HttpInputRequestResult> {
		@Override
		protected Builder self() {
			return this;
		}

		/**
		 * Builds a {@link HttpInputRequestResult}.
		 *
		 * @throws NullPointerException
		 *             if some of the required fields are null.
		 */
		public HttpInputRequestResult build() {

			return new HttpInputRequestResult(this);
		}
	}

	// ---------------------------------------------------------------------------------------------

	/**
	 * Json deserializer for {@link HttpInputRequestResult}
	 */
	public static final JsonpDeserializer<HttpInputRequestResult> _DESERIALIZER = ObjectBuilderDeserializer
			.lazy(Builder::new, HttpInputRequestResult::setupHttpInputRequestResultDeserializer, Builder::build);

	protected static void setupHttpInputRequestResultDeserializer(
			DelegatingDeserializer<HttpInputRequestResult.Builder> op) {
		HttpInputRequestDefinition.setupHttpInputRequestDefinitionDeserializer(op);

	}

}

==> elasticsearch-java-7.16.3-sources.jar: co/elastic/clients/elasticsearch/watcher/HttpInputRequestResult.java <==
/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

//----------------------------------------------------
// THIS CODE IS GENERATED. MANUAL EDITS WILL BE LOST.
//----------------------------------------------------

package co.elastic.clients.elasticsearch.watcher;

import co.elastic.clients.json.JsonpDeserializable;
import co.elastic.clients.json.JsonpDeserializer;
import co.elastic.clients.json.ObjectBuilderDeserializer;
import co.elastic.clients.json.ObjectDeserializer;
import co.elastic.clients.util.ObjectBuilder;
import jakarta.json.stream.JsonGenerator;
import java.util.Objects;
import java.util.function.Function;

// typedef: watcher._types.HttpInputRequestResult

/**
 *
 * @see <a href=
 *      "https://github.com/elastic/elasticsearch-specification/tree/98036c3/specification/watcher/_types/Actions.ts#L203-L203">API
 *      specification</a>
 */
@JsonpDeserializable
public class HttpInputRequestResult extends HttpInputRequestDefinition {
	// ---------------------------------------------------------------------------------------------

	private HttpInputRequestResult(Builder builder) {
		super(builder);

	}

	public static HttpInputRequestResult of(Function<Builder, ObjectBuilder<HttpInputRequestResult>> fn) {
		return fn.apply(new Builder()).build();
	}

	// ---------------------------------------------------------------------------------------------

	/**
	 * Builder for {@link HttpInputRequestResult}.
	 */

	public static class Builder extends HttpInputRequestDefinition.AbstractBuilder<Builder>
			implements
				ObjectBuilder<HttpInputRequestResult> {
		@Override
		protected Builder self() {
			return this;
		}

		/**
		 * Builds a {@link HttpInputRequestResult}.
		 *
		 * @throws NullPointerException
		 *             if some of the required fields are null.
		 */
		public HttpInputRequestResult build() {
			_checkSingleUse();

			return new HttpInputRequestResult(this);
		}
	}

	// ---------------------------------------------------------------------------------------------

	/**
	 * Json deserializer for {@link HttpInputRequestResult}
	 */
	public static final JsonpDeserializer<HttpInputRequestResult> _DESERIALIZER = ObjectBuilderDeserializer
			.lazy(Builder::new, HttpInputRequestResult::setupHttpInputRequestResultDeserializer);

	protected static void setupHttpInputRequestResultDeserializer(
			ObjectDeserializer<HttpInputRequestResult.Builder> op) {
		HttpInputRequestDefinition.setupHttpInputRequestDefinitionDeserializer(op);

	}

}
